==> army-0.0.2.tar.gz: army-0.0.2/src/gui/driver.h <==
//  Copyright (C) 2011 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#ifndef GUI_DRIVER_H
#define GUI_DRIVER_H

#include <memory>
#include <string>
#include <sigc++/trackable.h>

#include "game-window.h"
#include "game-parameters.h"

class Profile;
// takes care of setting up the splash window and the game window, the
// interaction between them and the model classes
// it also takes care of the game lobby window.
class Driver: public sigc::trackable
{
 public:
    Driver(std::string load_filename);
    ~Driver();

    void run();

 private:
    GameWindow* game_window;
    std::string d_load_filename;

    void on_new_game_requested(GameParameters g);
    void on_load_requested(std::string filename);
    void on_quit_requested();

    void on_game_ended();
    void on_game_ended_and_start_new();

    void init_game_window();


    GameScenario *new_game(GameParameters g);
    GameScenario *load_game(std::string file_path);

    GameScenario *create_new_scenario(GameParameters &g, GameScenario::PlayMode m);

    void get_default(int num_players, GameParameters &g);
  
};


#endif

==> army-0.0.3.tar.gz: army-0.0.3/src/gui/driver.h <==
//  Copyright (C) 2011, 2014 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#ifndef GUI_DRIVER_H
#define GUI_DRIVER_H

#include <memory>
#include <string>
#include <sigc++/trackable.h>

#include "game-window.h"
#include "game-parameters.h"

class Profile;
// takes care of setting up the splash window and the game window, the
// interaction between them and the model classes
// it also takes care of the game lobby window.
class Driver: public sigc::trackable
{
 public:
    Driver(Glib::ustring load_filename);
    ~Driver();

    void run();

 private:
    GameWindow* game_window;
    Glib::ustring d_load_filename;

    void on_new_game_requested(GameParameters g);
    void on_load_requested(Glib::ustring filename);
    void on_quit_requested();

    void on_game_ended();
    void on_game_ended_and_start_new();

    void init_game_window();


    GameScenario *new_game(GameParameters g);
    GameScenario *load_game(Glib::ustring file_path);

    GameScenario *create_new_scenario(GameParameters &g, GameScenario::PlayMode m);

    void get_default(int num_players, GameParameters &g);
  
};


#endif
